@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -29,9 +29,6 @@
 
 #include <string>
 
-#define FEATURE_COLOR 1
-
-////////////////////////////////////////////////////////////////////////////////
 #define _COLOR_INVERSE   0x00400000  // Inverse attribute.
 #define _COLOR_256       0x00200000  // 256-color mode.
 #define _COLOR_HASBG     0x00100000  // Has background color (all values taken).
@@ -52,18 +49,16 @@ public:
   Color (unsigned int);                         // 256 | INVERSE | UNDERLINE | BOLD | BRIGHT | (BG << 8) | FG
   Color (const std::string&);                   // "red on bright black"
   Color (color_id);                             // fg.
-  Color (color_id, color_id);                   // fg, bg.
   Color (color_id, color_id, bool, bool, bool); // fg, bg, underline, bold, bright
-  ~Color ();
-  Color& operator= (const Color&);
   operator std::string () const;
   operator int () const;
 
   void upgrade ();
   void blend (const Color&);
 
-  std::string colorize (const std::string&);
+  std::string colorize (const std::string&) const;
   static std::string colorize (const std::string&, const std::string&);
+  void _colorize (std::string&, const std::string&) const;
   static std::string strip (const std::string&);
 
   bool nontrivial () const;
@@ -78,5 +73,3 @@ private:
 };
 
 #endif
-
-////////////////////////////////////////////////////////////////////////////////
