@@ -1,7 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
-// taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2013, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,85 +24,91 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#define L10N                                           // Localization complete.
-
+#include <cmake.h>
+#include <CmdDone.h>
 #include <iostream>
 #include <Context.h>
+#include <Filter.h>
 #include <util.h>
 #include <text.h>
 #include <i18n.h>
 #include <main.h>
-#include <CmdDone.h>
 
 extern Context context;
 
 ////////////////////////////////////////////////////////////////////////////////
 CmdDone::CmdDone ()
 {
-  _keyword     = "done";
-  _usage       = "task <filter> done <mods>";
-  _description = STRING_CMD_DONE_USAGE;
-  _read_only   = false;
-  _displays_id = false;
+  _keyword               = "done";
+  _usage                 = "task <filter> done <mods>";
+  _description           = STRING_CMD_DONE_USAGE;
+  _read_only             = false;
+  _displays_id           = false;
+  _needs_gc              = false;
+  _uses_context          = true;
+  _accepts_filter        = true;
+  _accepts_modifications = true;
+  _accepts_miscellaneous = false;
+  _category              = Command::Category::operation;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-int CmdDone::execute (std::string& output)
+int CmdDone::execute (std::string&)
 {
   int rc = 0;
   int count = 0;
 
   // Apply filter.
+  Filter filter;
   std::vector <Task> filtered;
-  filter (filtered);
+  filter.subset (filtered);
   if (filtered.size () == 0)
   {
     context.footnote (STRING_FEEDBACK_NO_TASKS_SP);
     return 1;
   }
 
-  // Apply the command line modifications to the new task.
-  A3 modifications = context.a3.extract_modifications ();
-
   // Accumulated project change notifications.
   std::map <std::string, std::string> projectChanges;
 
   bool nagged = false;
-  std::vector <Task>::iterator task;
-  for (task = filtered.begin (); task != filtered.end (); ++task)
+  for (auto& task : filtered)
   {
-    Task before (*task);
+    Task before (task);
 
-    if (task->getStatus () == Task::pending ||
-        task->getStatus () == Task::waiting)
+    if (task.getStatus () == Task::pending ||
+        task.getStatus () == Task::waiting)
     {
       // Complete the specified task.
       std::string question = format (STRING_CMD_DONE_CONFIRM,
-                                     task->id,
-                                     task->get ("description"));
+                                     task.identifier (true),
+                                     task.get ("description"));
 
-      modify_task_annotate (*task, modifications);
-      task->setStatus (Task::completed);
-      if (! task->has ("end"))
-        task->setEnd ();
+      task.modify (Task::modAnnotate);
+      task.setStatus (Task::completed);
+      if (! task.has ("end"))
+        task.setAsNow ("end");
 
       // Stop the task, if started.
-      if (task->has ("start") &&
-          context.config.getBoolean ("journal.time"))
-        task->addAnnotation (context.config.get ("journal.time.stop.annotation"));
-
-      if (permission (*task, taskDifferences (before, *task) + question, filtered.size ()))
+      if (task.has ("start"))
       {
-        updateRecurrenceMask (*task);
-        context.tdb2.modify (*task);
+        task.remove ("start");
+        if (context.config.getBoolean ("journal.time"))
+          task.addAnnotation (context.config.get ("journal.time.stop.annotation"));
+      }
+
+      if (permission (taskDifferences (before, task) + question, filtered.size ()))
+      {
+        updateRecurrenceMask (task);
+        context.tdb2.modify (task);
         ++count;
-        feedback_affected (STRING_CMD_DONE_TASK, *task);
-        feedback_unblocked (*task);
+        feedback_affected (STRING_CMD_DONE_TASK, task);
+        feedback_unblocked (task);
         if (!nagged)
-          nagged = nag (*task);
-        dependencyChainOnComplete (*task);
+          nagged = nag (task);
+        dependencyChainOnComplete (task);
         if (context.verbose ("project"))
-          projectChanges[task->get ("project")] = onProjectChange (*task);
+          projectChanges[task.get ("project")] = onProjectChange (task);
       }
       else
       {
@@ -116,20 +121,18 @@ int CmdDone::execute (std::string& output)
     else
     {
       std::cout << format (STRING_CMD_DONE_NOTPEND,
-                           task->id,
-                           task->get ("description"))
+                           task.identifier (true),
+                           task.get ("description"))
                 << "\n";
       rc = 1;
     }
   }
 
   // Now list the project changes.
-  std::map <std::string, std::string>::iterator i;
-  for (i = projectChanges.begin (); i != projectChanges.end (); ++i)
-    if (i->first != "")
-      context.footnote (i->second);
+  for (auto& change : projectChanges)
+    if (change.first != "")
+      context.footnote (change.second);
 
-  context.tdb2.commit ();
   feedback_affected (count == 1 ? STRING_CMD_DONE_1 : STRING_CMD_DONE_N, count);
   return rc;
 }
